# numberwords.py
# --------------
# By MWC Contributors
# Functions to print out a verbal representation of an integer.

MAXIMUM = 1000000
DIGIT_NAMES = [
    "zero", "one", "two", "three", "four", "five", "six", "seven", "eight", "nine"
]
TWEEN_AND_TEEN_NAMES = [
    "ten", "eleven", "twelve", "thirteen", "fourteen", "fifteen", "sixteen", "seventeen", "eighteen", "nineteen"
]
TENS_NAMES = [
    "", "ten", "twenty", "thirty", "forty", "fifty", "sixty", "seventy", "eighty", "ninety"
]

def int_under_1000000_to_str(number):
    if number < 1000:
        return int_under_1000_to_str(number)
    else:
        thousands, hundreds_tens_ones = divide_with_remainder(number, 1000)
        if hundreds_tens_ones == 0:
            return int_under_1000_to_str(thousands) + " thousand"
        else:
            return int_under_1000_to_str(thousands) + " thousand " + int_under_1000_to_str(hundreds_tens_ones) 
        
def int_under_1000_to_str(number):
    if number < 100:
        return int_under_100_to_str(number)
    else:
        hundreds, tens_and_ones = divide_with_remainder(number, 100)
        if tens_and_ones == 0:
            return int_under_10_to_str(hundreds) + " hundred"
        else:
            return int_under_10_to_str(hundreds) + " hundred and " + int_under_100_to_str(tens_and_ones)


def int_under_100_to_str(number):
    if number < 20:
        return int_under_20_to_str(number) 
    else:
        tens, ones = divide_with_remainder(number, 10)
        if ones == 0:
            return TENS_NAMES[tens]
        else:
            return TENS_NAMES[tens] + "-" + int_under_10_to_str(ones)

def int_under_20_to_str(number):
    if number < 10:
        return int_under_10_to_str(number)
    else:
        return TWEEN_AND_TEEN_NAMES[number-10]    

def int_under_10_to_str(number):
    return DIGIT_NAMES[number]

def check_number_in_range(number, minimum, maximum):
    """Checks whether a number is at least minimum and less than maximum. 
    Raises an error if the number is not in range.
    """
    if number < minimum:
        raise ValueError(f"{number} must not be below {minimum}.")
    if number >= maximum:
        raise ValueError(f"{number} must be less than {maximum}.")

def divide_with_remainder(dividend, divisor):
    """Divides one number by another, using whole-number division. 
    Returns the quotient and the remainder.
    Note how a function can return more than one value!
    """
    quotient = dividend // divisor
    remainder = dividend % divisor
    return quotient, remainder
